.. beartype_sphinx documentation master file, created by
   sphinx-quickstart on Wed Nov  3 00:24:42 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to beartype_sphinx's documentation!
================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: beartype_sphinx
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
